==> je-1.5.3-sources.jar: com/sleepycat/je/log/CheckpointMonitor.java <==
/*-
* See the file LICENSE for redistribution information.
*
* Copyright (c) 2002-2004
*      Sleepycat Software.  All rights reserved.
*
* $Id: CheckpointMonitor.java,v 1.2 2004/08/18 14:02:04 mark Exp $
*/

package com.sleepycat.je.log;

import com.sleepycat.je.DatabaseException;
import com.sleepycat.je.config.EnvironmentParams;
import com.sleepycat.je.dbi.EnvironmentImpl;

/**
 * The checkpoint monitor saves information about log writes to decide
 * when a checkpoint is needed.
 */
class CheckpointMonitor {
    private int bytesWritten;
    private long periodInBytes;
    private EnvironmentImpl envImpl;

    CheckpointMonitor(EnvironmentImpl envImpl)
        throws DatabaseException {
        	
        bytesWritten = 0;
        periodInBytes = envImpl.getConfigManager().getLong(
                             EnvironmentParams.CHECKPOINTER_BYTES_INTERVAL);
        /*
         * The period is reset each activation and is not synchronized with
         * the interval counted by the Checkpointer.  Use a small enough
         * period to invoke the Checkpointer within 10% of its interval.
         */
        periodInBytes /= 10;
        this.envImpl = envImpl;
    }

    /**
     * Update checkpoint driving information. Call from within the
     * log write latch.
     * @return true if a checkpoint is needed.
     */
    boolean recordLogWrite(int entrySize, LoggableObject item) {
        bytesWritten += entrySize;
        return (bytesWritten >= periodInBytes);
    }

    /**
     * Wake up the checkpointer. Note that the check on bytesWritten is
     * actually within a latched period.
     */
    void activate() {
        envImpl.getCheckpointer().wakeup();
        bytesWritten = 0;
    }            
}

==> je-2.0.90-sources.jar: com/sleepycat/je/log/CheckpointMonitor.java <==
/*-
* See the file LICENSE for redistribution information.
*
* Copyright (c) 2002-2005
*      Sleepycat Software.  All rights reserved.
*
* $Id: CheckpointMonitor.java,v 1.5 2004/12/22 14:11:33 linda Exp $
*/

package com.sleepycat.je.log;

import com.sleepycat.je.DatabaseException;
import com.sleepycat.je.config.EnvironmentParams;
import com.sleepycat.je.dbi.EnvironmentImpl;

/**
 * The checkpoint monitor saves information about log writes to decide when a
 * checkpoint is needed.
 */
class CheckpointMonitor {
    private int bytesWritten;
    private long periodInBytes;
    private EnvironmentImpl envImpl;

    CheckpointMonitor(EnvironmentImpl envImpl)
        throws DatabaseException {
        	
        bytesWritten = 0;
        periodInBytes = envImpl.getConfigManager().getLong
	    (EnvironmentParams.CHECKPOINTER_BYTES_INTERVAL);

        /*
         * The period is reset each activation and is not synchronized with the
         * interval counted by the Checkpointer.  Use a small enough period to
         * invoke the Checkpointer within 10% of its interval.
         */
        periodInBytes /= 10;
        this.envImpl = envImpl;
    }

    /**
     * Update checkpoint driving information. Call from within the log write
     * latch.
     *
     * @return true if a checkpoint is needed.
     */
    boolean recordLogWrite(int entrySize, LoggableObject item) {
        bytesWritten += entrySize;
        return (bytesWritten >= periodInBytes);
    }

    /**
     * Wake up the checkpointer. Note that the check on bytesWritten is
     * actually within a latched period.
     */
    void activate() {
        envImpl.getCheckpointer().wakeup();
        bytesWritten = 0;
    }            
}
